aboutsummaryrefslogtreecommitdiffstats
path: root/include/gwin/button.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/gwin/button.h')
-rw-r--r--include/gwin/button.h22
1 files changed, 10 insertions, 12 deletions
diff --git a/include/gwin/button.h b/include/gwin/button.h
index 2df540da..3d54afbb 100644
--- a/include/gwin/button.h
+++ b/include/gwin/button.h
@@ -180,30 +180,28 @@ void gwinSetButtonCustom(GHandle gh, GButtonDrawFunction fn, void *param);
*/
#define gwinGetButtonSource(gh) ((GSourceHandle)(gh))
-#if defined(GINPUT_NEED_MOUSE) && GINPUT_NEED_MOUSE
+#if GFX_USE_GINPUT && GINPUT_NEED_MOUSE
/**
- * @brief Attach a mouse source
- * @details Attach a mouse source to a given button
+ * @brief Attach a mouse to a button
*
* @param[in] gh The button handle
* @param[in] gsh The source handle
*
* @api
*/
- bool_t gwinAttachButtonMouseSource(GHandle gh, GSourceHandle gsh);
+ bool_t gwinAttachButtonMouse(GHandle gh, uint16_t instance);
#endif
-#if defined(GINPUT_NEED_TOGGLE) && GINPUT_NEED_TOGGLE
+#if GFX_USE_GINPUT && GINPUT_NEED_TOGGLE
/**
- * @brief Attach a toggle source
- * @details Attach a toggle source to this button
+ * @brief Attach a toggle to a button
*
* @param[in] gh The button handle
* @param[in] gsh The source handle
*
* @api
*/
- bool_t gwinAttachButtonToggleSource(GHandle gh, GSourceHandle gsh);
+ bool_t gwinAttachButtonToggle(GHandle gh, uint16_t instance);
#endif
/**
@@ -180,30 +180,28 @@ void gwinSetButtonCustom(GHandle gh, GButtonDrawFunction fn, void *param);
*
- * @param[in] gh The button handle
- * @param[in] gsh The source handle
+ * @param[in] gh The button handle
+ * @param[in] instance The mouse instance
*
* @api
@@ -180,30 +180,28 @@ void gwinSetButtonCustom(GHandle gh, GButtonDrawFunction fn, void *param);
*
- * @param[in] gh The button handle
- * @param[in] gsh The source handle
+ * @param[in] gh The button handle
+ * @param[in] instance The toggle instance
*
* @api